# Configure paths for dpsftplib
# Modified from gtk.m4 by Own Taylor

dnl AM_PATH_DPSFTPLIB([MINIMUM-VERSION, [ACTION-IF-FOUND [, ACTION-IF-NOT-FOUND [, MODULES]]]])
dnl Test for dpsftplib, and define DPSFTPLIB_CFLAGS and DPSFTPLIB_LIBS
dnl
AC_DEFUN(AM_PATH_DPSFTPLIB,
[dnl 
dnl Get the cflags and libraries from the dpsftplib-config script
dnl
AC_ARG_WITH(dpsftplib-prefix,[  --with-dpsftplib-prefix=PFX   Prefix where dpsftplib is installed (optional)],
            dpsftplib_config_prefix="$withval", dpsftplib_config_prefix="")
AC_ARG_WITH(dpsftplib-exec-prefix,[  --with-dpsftplib-exec-prefix=PFX Exec prefix where dpsftplib is installed (optional)],
            dpsftplib_config_exec_prefix="$withval", dpsftplib_config_exec_prefix="")
AC_ARG_ENABLE(dpsftplibtest, [  --disable-dpsftplibtest       Do not try to compile and run a test dpsftplib program],
		    , enable_dpsftplibtest=yes)

  for module in . $4
  do
      case "$module" in
         gthread) 
             dpsftplib_config_args="$dpsftplib_config_args gthread"
         ;;
      esac
  done

  if test x$dpsftplib_config_exec_prefix != x ; then
     dpsftplib_config_args="$dpsftplib_config_args --exec-prefix=$dpsftplib_config_exec_prefix"
     if test x${DPSFTPLIB_CONFIG+set} != xset ; then
        DPSFTPLIB_CONFIG=$dpsftplib_config_exec_prefix/bin/dpsftplib-config
     fi
  fi
  if test x$dpsftplib_config_prefix != x ; then
     dpsftplib_config_args="$dpsftplib_config_args --prefix=$dpsftplib_config_prefix"
     if test x${DPSFTPLIB_CONFIG+set} != xset ; then
        DPSFTPLIB_CONFIG=$dpsftplib_config_prefix/bin/dpsftplib-config
     fi
  fi

  AC_PATH_PROG(DPSFTPLIB_CONFIG, dpsftplib-config, no)
  min_dpsftplib_version=ifelse([$1], ,0.99.7,$1)
  AC_MSG_CHECKING(for dpsftplib - version >= $min_dpsftplib_version)
  no_dpsftplib=""
  if test "$DPSFTPLIB_CONFIG" = "no" ; then
    no_dpsftplib=yes
  else
    DPSFTPLIB_CFLAGS=`$DPSFTPLIB_CONFIG $dpsftplib_config_args --cflags`
    DPSFTPLIB_LIBS=`$DPSFTPLIB_CONFIG $dpsftplib_config_args --libs`
    dpsftplib_config_major_version=`$DPSFTPLIB_CONFIG $dpsftplib_config_args --version | \
           sed 's/\([[0-9]]*\).\([[0-9]]*\).\([[0-9]]*\)/\1/'`
    dpsftplib_config_minor_version=`$DPSFTPLIB_CONFIG $dpsftplib_config_args --version | \
           sed 's/\([[0-9]]*\).\([[0-9]]*\).\([[0-9]]*\)/\2/'`
    dpsftplib_config_micro_version=`$DPSFTPLIB_CONFIG $dpsftplib_config_args --version | \
           sed 's/\([[0-9]]*\).\([[0-9]]*\).\([[0-9]]*\)/\3/'`
    if test "x$enable_dpsftplibtest" = "xyes" ; then
      ac_save_CFLAGS="$CFLAGS"
      ac_save_LIBS="$LIBS"
      CFLAGS="$CFLAGS $DPSFTPLIB_CFLAGS -DHAVE_PTHREADS"
      LIBS="$DPSFTPLIB_LIBS $LIBS"
dnl
dnl Now check if the installed dpsftplib is sufficiently new. (Also sanity
dnl checks the results of dpsftplib-config to some extent
dnl
      rm -f conf.dpsftplibtest
      AC_TRY_RUN([
#include <dpsftplib.h>
#include <stdio.h>
#include <stdlib.h>

int 
main ()
{
  int major, minor, micro;
  char *tmp_version;

  system ("touch conf.dpsftplibtest");

  /* HP/UX 9 (%@#!) writes to sscanf strings */
  tmp_version = g_strdup("$min_dpsftplib_version");
  if (sscanf(tmp_version, "%d.%d.%d", &major, &minor, &micro) != 3) {
     printf("%s, bad version string\n", "$min_dpsftplib_version");
     exit(1);
   }

  if ((dpsftplib_major_version != $dpsftplib_config_major_version) ||
      (dpsftplib_minor_version != $dpsftplib_config_minor_version) ||
      (dpsftplib_micro_version != $dpsftplib_config_micro_version))
    {
      printf("\n*** 'dpsftplib-config --version' returned %d.%d.%d, but dpsftplib+ (%d.%d.%d)\n", 
             $dpsftplib_config_major_version, $dpsftplib_config_minor_version, $dpsftplib_config_micro_version,
             dpsftplib_major_version, dpsftplib_minor_version, dpsftplib_micro_version);
      printf ("*** was found! If dpsftplib-config was correct, then it is best\n");
      printf ("*** to remove the old version of dpsftplib. You may also be able to fix the error\n");
      printf("*** by modifying your LD_LIBRARY_PATH enviroment variable, or by editing\n");
      printf("*** /etc/ld.so.conf. Make sure you have run ldconfig if that is\n");
      printf("*** required on your system.\n");
      printf("*** If dpsftplib-config was wrong, set the environment variable DPSFTPLIB_CONFIG\n");
      printf("*** to point to the correct copy of dpsftplib-config, and remove the file config.cache\n");
      printf("*** before re-running configure\n");
    } 
#if defined (DPSFTPLIB_MAJOR_VERSION) && defined (DPSFTPLIB_MINOR_VERSION) && defined (DPSFTPLIB_MICRO_VERSION)
  else if ((dpsftplib_major_version != DPSFTPLIB_MAJOR_VERSION) ||
	   (dpsftplib_minor_version != DPSFTPLIB_MINOR_VERSION) ||
           (dpsftplib_micro_version != DPSFTPLIB_MICRO_VERSION))
    {
      printf("*** dpsftplib header files (version %d.%d.%d) do not match\n",
	     DPSFTPLIB_MAJOR_VERSION, DPSFTPLIB_MINOR_VERSION, DPSFTPLIB_MICRO_VERSION);
      printf("*** library (version %d.%d.%d)\n",
	     dpsftplib_major_version, dpsftplib_minor_version, dpsftplib_micro_version);
    }
#endif /* defined (DPSFTPLIB_MAJOR_VERSION) ... */
  else
    {
      if ((dpsftplib_major_version > major) ||
        ((dpsftplib_major_version == major) && (dpsftplib_minor_version > minor)) ||
        ((dpsftplib_major_version == major) && (dpsftplib_minor_version == minor) && (dpsftplib_micro_version >= micro)))
      {
        return 0;
       }
     else
      {
        printf("\n*** An old version of dpsftplib (%d.%d.%d) was found.\n",
               dpsftplib_major_version, dpsftplib_minor_version, dpsftplib_micro_version);
        printf("*** You need a version of dpsftplib newer than %d.%d.%d. The latest version of\n",
	       major, minor, micro);
        printf("*** dpsftplib is always available from ftp://ftp.dpsftplib.org.\n");
        printf("***\n");
        printf("*** If you have already installed a sufficiently new version, this error\n");
        printf("*** probably means that the wrong copy of the dpsftplib-config shell script is\n");
        printf("*** being found. The easiest way to fix this is to remove the old version\n");
        printf("*** of dpsftplib, but you can also set the DPSFTPLIB_CONFIG environment to point to the\n");
        printf("*** correct copy of dpsftplib-config. (In this case, you will have to\n");
        printf("*** modify your LD_LIBRARY_PATH enviroment variable, or edit /etc/ld.so.conf\n");
        printf("*** so that the correct libraries are found at run-time))\n");
      }
    }
  return 1;
}
],, no_dpsftplib=yes,[echo $ac_n "cross compiling; assumed OK... $ac_c"])
       CFLAGS="$ac_save_CFLAGS"
       LIBS="$ac_save_LIBS"
     fi
  fi
  if test "x$no_dpsftplib" = x ; then
     AC_MSG_RESULT(yes)
     ifelse([$2], , :, [$2])     
  else
     AC_MSG_RESULT(no)
     if test "$DPSFTPLIB_CONFIG" = "no" ; then
       echo "*** The dpsftplib-config script installed by dpsftplib could not be found"
       echo "*** If dpsftplib was installed in PREFIX, make sure PREFIX/bin is in"
       echo "*** your path, or set the DPSFTPLIB_CONFIG environment variable to the"
       echo "*** full path to dpsftplib-config."
     else
       if test -f conf.dpsftplibtest ; then
        :
       else
          echo "*** Could not run dpsftplib test program, checking why..."
          CFLAGS="$CFLAGS $DPSFTPLIB_CFLAGS -DHAVE_PTHREADS"
          LIBS="$LIBS $DPSFTPLIB_LIBS"
          AC_TRY_LINK([
#include <dpsftplib.h>
#include <stdio.h>
],      [ return ((dpsftplib_major_version) || (dpsftplib_minor_version) || (dpsftplib_micro_version)); ],
        [ echo "*** The test program compiled, but did not run. This usually means"
          echo "*** that the run-time linker is not finding dpsftplib or finding the wrong"
          echo "*** version of dpsftplib. If it is not finding dpsftplib, you'll need to set your"
          echo "*** LD_LIBRARY_PATH environment variable, or edit /etc/ld.so.conf to point"
          echo "*** to the installed location  Also, make sure you have run ldconfig if that"
          echo "*** is required on your system"
	  echo "***"
          echo "*** If you have an old version installed, it is best to remove it, although"
          echo "*** you may also be able to get things to work by modifying LD_LIBRARY_PATH"
          echo "***"
          echo "*** If you have a RedHat 5.0 system, you should remove the dpsftplib package that"
          echo "*** came with the system with the command"
          echo "***"
          echo "***    rpm --erase --nodeps dpsftplib dpsftplib-devel" ],
        [ echo "*** The test program failed to compile or link. See the file config.log for the"
          echo "*** exact error that occured. This usually means dpsftplib was incorrectly installed"
          echo "*** or that you have moved dpsftplib since it was installed. In the latter case, you"
          echo "*** may want to edit the dpsftplib-config script: $DPSFTPLIB_CONFIG" ])
          CFLAGS="$ac_save_CFLAGS"
          LIBS="$ac_save_LIBS"
       fi
     fi
     DPSFTPLIB_CFLAGS=""
     DPSFTPLIB_LIBS=""
     ifelse([$3], , :, [$3])
  fi
  AC_SUBST(DPSFTPLIB_CFLAGS)
  AC_SUBST(DPSFTPLIB_LIBS)
  rm -f conf.dpsftplibtest
])
